pilas.interpolaciones

Package pilas :: Module interpolaciones |
[hide private]
[frames] | no frames]

# Module interpolaciones

source code

Classes | [hide private]
| Interpolacion Representa una interpolacion, que pasa por varios puntos clave.
| Lineal Representa una interpolación lineal.
| AceleracionGradual Representa una interpolación con aceleración gradual.
| DesaceleracionGradual Representa una interpolación con aceleración gradual.
| ReboteInicial Representa una interpolación con rebote.
| ReboteFinal Representa una interpolación con rebote.
| ElasticoInicial Representa una interpolación con rebote.
| ElasticoFinal Representa una interpolación con rebote.

Variables | [hide private]
| __package__ = ``'``pilas``'``